@@ -20,7 +20,7 @@ use Carp qw( carp );
 use Mojo::Util qw( monkey_patch );
 
 # ABSTRACT: Construct command line and perl clients for RESTful services.
-our $VERSION = '1.14'; # VERSION
+our $VERSION = '1.15'; # VERSION
 
 
 has server_url => '';
@@ -636,7 +636,7 @@ Clustericious::Client - Construct command line and perl clients for RESTful serv
 
 =head1 VERSION
 
-version 1.14
+version 1.15
 
 =head1 SYNOPSIS
 
@@ -1010,7 +1010,7 @@ Returns a Clustericious::Client::Meta::Route object.
 =head1 COMMON ROUTES
 
 These are routes that are automatically supported by all clients.
-See L<Clustericious::RouteBuilder::Common>.
+See L<Clustericious::Plugin::CommonRoutes>.
 
 =head2 version
 
