@@ -8,8 +8,7 @@ use Clustericious::Config;
 use YAML::XS qw( Dump );
 
 # ABSTRACT: Dump a clustericious configuration
-our $VERSION = '1.28_01'; # TRIAL VERSION
-$VERSION = eval $VERSION;
+our $VERSION = '1.15'; # VERSION
 
 
 has description => <<EOT;
@@ -61,7 +60,7 @@ Clustericious::Command::configdump - Dump a clustericious configuration
 
 =head1 VERSION
 
-version 1.28_01
+version 1.15
 
 =head1 SYNOPSIS
 
@@ -92,8 +91,6 @@ Contributors:
 
 Curt Tilmes
 
-Yanick Champoux
-
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2013 by NASA GSFC.
